@@ -21,12 +21,13 @@ pub use namespace::NamespaceExt;
 pub use pod_spec::PodSpecExt;
 pub use pod_template_spec::PodTemplateSpecExt;
 pub use policy_rule::PolicyRuleExt;
+pub use probe::ProbeExt;
 pub use role::RoleExt;
 pub use role_binding::RoleBindingExt;
 pub use role_ref::RoleRefExt;
 pub use secret::SecretExt;
-pub use service_account::ServiceAccountExt;
 pub use service::ServiceExt;
+pub use service_account::ServiceAccountExt;
 pub use subject::SubjectExt;
 
 mod cluster_role;
@@ -41,6 +42,7 @@ mod namespace;
 mod pod_spec;
 mod pod_template_spec;
 mod policy_rule;
+mod probe;
 mod role;
 mod role_binding;
 mod role_ref;
